# last modified 5 Dec 04 by J. Fox

"hetcor" <-
function(data, ..., ML=FALSE, std.err=TRUE, bins=4){
  UseMethod("hetcor")
  }
